@@ -38,6 +38,7 @@ from botocore.model import DenormalizedStructureBuilder
 from botocore.session import Session
 from botocore.signers import RequestSigner
 from botocore.credentials import Credentials
+from botocore.utils import conditionally_calculate_md5
 from botocore import handlers
 
 
@@ -761,6 +762,16 @@ class TestHandlers(BaseSessionTest):
         except ParamValidationError:
             self.fail('The s3 arn: %s should pass validation' % arn)
 
+    def test_validation_is_s3_outpost_arn(self):
+        try:
+            arn = (
+                'arn:aws:s3-outposts:us-west-2:123456789012:outpost:'
+                'op-01234567890123456:accesspoint:myaccesspoint'
+            )
+            handlers.validate_bucket_name({'Bucket': arn})
+        except ParamValidationError:
+            self.fail('The s3 arn: %s should pass validation' % arn)
+
     def test_validation_is_global_s3_bucket_arn(self):
         with self.assertRaises(ParamValidationError):
             arn = 'arn:aws:s3:::mybucket'
@@ -921,13 +932,6 @@ class TestHandlers(BaseSessionTest):
         self.assertEqual(parsed['CommonPrefixes'][0]['Prefix'],
                          u'\xe7\xf6s% asd\x08 c')
 
-    def test_get_bucket_location_optional(self):
-        # This handler should no-op if another hook (i.e. stubber) has already
-        # filled in response
-        response = {"LocationConstraint": "eu-west-1"}
-        handlers.parse_get_bucket_location(response, None),
-        self.assertEqual(response["LocationConstraint"], "eu-west-1")
-
     def test_set_operation_specific_signer_no_auth_type(self):
         signing_name = 'myservice'
         context = {'auth_type': None}
@@ -1131,7 +1135,7 @@ class TestAddMD5(BaseMD5Test):
                         'method': 'PUT',
                         'headers': {}}
         context = self.get_context()
-        handlers.conditionally_calculate_md5(
+        conditionally_calculate_md5(
             request_dict, request_signer=request_signer, context=context)
         self.assertTrue('Content-MD5' in request_dict['headers'])
 
@@ -1145,7 +1149,7 @@ class TestAddMD5(BaseMD5Test):
                         'method': 'PUT',
                         'headers': {}}
         context = self.get_context({'payload_signing_enabled': False})
-        handlers.conditionally_calculate_md5(
+        conditionally_calculate_md5(
             request_dict, request_signer=request_signer, context=context)
         self.assertTrue('Content-MD5' in request_dict['headers'])
 
@@ -1160,8 +1164,8 @@ class TestAddMD5(BaseMD5Test):
 
         context = self.get_context()
         self.set_md5_available(False)
-        with mock.patch('botocore.handlers.MD5_AVAILABLE', False):
-            handlers.conditionally_calculate_md5(
+        with mock.patch('botocore.utils.MD5_AVAILABLE', False):
+            conditionally_calculate_md5(
                 request_dict, request_signer=request_signer, context=context)
             self.assertFalse('Content-MD5' in request_dict['headers'])
 
@@ -1176,7 +1180,7 @@ class TestAddMD5(BaseMD5Test):
 
         self.set_md5_available(False)
         with self.assertRaises(MD5UnavailableError):
-            handlers.calculate_md5(
+            conditionally_calculate_md5(
                 request_dict, request_signer=request_signer)
 
     def test_adds_md5_when_s3v2(self):
@@ -1188,7 +1192,7 @@ class TestAddMD5(BaseMD5Test):
                         'method': 'PUT',
                         'headers': {}}
         context = self.get_context()
-        handlers.conditionally_calculate_md5(
+        conditionally_calculate_md5(
             request_dict, request_signer=request_signer, context=context)
         self.assertTrue('Content-MD5' in request_dict['headers'])
 
@@ -1198,7 +1202,7 @@ class TestAddMD5(BaseMD5Test):
             'headers': {}
         }
         self.md5_digest.return_value = b'8X\xf6"0\xac<\x91_0\x0cfC\x12\xc6?'
-        handlers.calculate_md5(request_dict)
+        conditionally_calculate_md5(request_dict)
         self.assertEqual(request_dict['headers']['Content-MD5'],
                          'OFj2IjCsPJFfMAxmQxLGPw==')
 
@@ -1208,7 +1212,7 @@ class TestAddMD5(BaseMD5Test):
             'headers': {}
         }
         self.md5_digest.return_value = b'8X\xf6"0\xac<\x91_0\x0cfC\x12\xc6?'
-        handlers.calculate_md5(request_dict)
+        conditionally_calculate_md5(request_dict)
         self.assertEqual(
             request_dict['headers']['Content-MD5'],
             'OFj2IjCsPJFfMAxmQxLGPw==')
@@ -1219,7 +1223,7 @@ class TestAddMD5(BaseMD5Test):
             'headers': {}
         }
         self.md5_digest.return_value = b'8X\xf6"0\xac<\x91_0\x0cfC\x12\xc6?'
-        handlers.calculate_md5(request_dict)
+        conditionally_calculate_md5(request_dict)
         self.assertEqual(
             request_dict['headers']['Content-MD5'],
             'OFj2IjCsPJFfMAxmQxLGPw==')
